#!/usr/bin/env perl
# PODNAME: app.pl
# ABSTRACT: Script to run this dancer app
use Dancer;
use App::Beeminder::Hook;
dance;

__END__
=pod

=head1 NAME

app.pl - Script to run this dancer app

=head1 VERSION

version 0.003

=head1 AUTHOR

Jonathan "Duke" Leto <jonathan@leto.net>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Leto Labs LLC.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

